// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: adb_host.proto
// Protobuf C++ Version: 7.35.1

#include "adb_host.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
#ifdef PROTOBUF_MESSAGE_GLOBALS
namespace {
PROTOBUF_CONSTINIT ::google::protobuf::internal::ReflectionData
    file_reflection_data[] = {
        // ::adb::proto::Device
        {&::_pbi::kDescriptorMethods, &::descriptor_table_adb_5fhost_2eproto, /* tracker*/ nullptr,},
        // ::adb::proto::Devices
        {&::_pbi::kDescriptorMethods, &::descriptor_table_adb_5fhost_2eproto, /* tracker*/ nullptr,},
        // ::adb::proto::AdbServerStatus
        {&::_pbi::kDescriptorMethods, &::descriptor_table_adb_5fhost_2eproto, /* tracker*/ nullptr,},
        // ::adb::proto::MdnsServices
        {&::_pbi::kDescriptorMethods, &::descriptor_table_adb_5fhost_2eproto, /* tracker*/ nullptr,},
        // ::adb::proto::ServiceAdbTcp
        {&::_pbi::kDescriptorMethods, &::descriptor_table_adb_5fhost_2eproto, /* tracker*/ nullptr,},
        // ::adb::proto::ServiceAdbTls
        {&::_pbi::kDescriptorMethods, &::descriptor_table_adb_5fhost_2eproto, /* tracker*/ nullptr,},
        // ::adb::proto::ServiceAdbPairing
        {&::_pbi::kDescriptorMethods, &::descriptor_table_adb_5fhost_2eproto, /* tracker*/ nullptr,},
        // ::adb::proto::MdnsService
        {&::_pbi::kDescriptorMethods, &::descriptor_table_adb_5fhost_2eproto, /* tracker*/ nullptr,},
};
}  // namespace
#endif
namespace adb {
namespace proto {
class MdnsService::_Internal {
 public:
  using HasBits = decltype(::std::declval<MdnsService>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(MdnsService, _impl_._has_bits_);
};

constexpr MdnsService::ParseTableT_ MdnsService::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(MdnsService, _impl_._has_bits_),
      0, // no _extensions_
      12, 120,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294963200,  // skipmap
      offsetof(ParseTableT_, field_entries),
      12,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::adb::proto::MdnsService>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string instance = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 1, 0,
        PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.instance_)}},
      // string service = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 2, 0,
        PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.service_)}},
      // string domain = 3;
      {::_pbi::TcParser::FastUS1,
       {26, 3, 0,
        PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.domain_)}},
      // optional string ipv4 = 4;
      {::_pbi::TcParser::FastUS1,
       {34, 4, 0,
        PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.ipv4_)}},
      // repeated string ipv6 = 5;
      {::_pbi::TcParser::FastUR1,
       {42, 0, 0,
        PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.ipv6_)}},
      // uint32 port = 6;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(MdnsService, _impl_.port_), 11>(),
       {48, 11, 0,
        PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.port_)}},
      // optional string product_model = 7;
      {::_pbi::TcParser::FastUS1,
       {58, 5, 0,
        PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.product_model_)}},
      // optional string build_version_sdk_full = 8;
      {::_pbi::TcParser::FastUS1,
       {66, 6, 0,
        PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.build_version_sdk_full_)}},
      // optional string given_name = 9;
      {::_pbi::TcParser::FastUS1,
       {74, 7, 0,
        PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.given_name_)}},
      // optional string serial = 10;
      {::_pbi::TcParser::FastUS1,
       {82, 8, 0,
        PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.serial_)}},
      // optional string mdns_service_version = 11;
      {::_pbi::TcParser::FastUS1,
       {90, 9, 0,
        PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.mdns_service_version_)}},
      // optional string hostname = 12;
      {::_pbi::TcParser::FastUS1,
       {98, 10, 0,
        PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.hostname_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // string instance = 1;
      {PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.instance_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string service = 2;
      {PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.service_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string domain = 3;
      {PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.domain_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // optional string ipv4 = 4;
      {PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.ipv4_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // repeated string ipv6 = 5;
      {PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.ipv6_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kUtf8String | ::_fl::kRepSString)},
      // uint32 port = 6;
      {PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.port_), _Internal::kHasBitsOffset + 11, 0, (0 | ::_fl::kFcOptional | ::_fl::kUInt32)},
      // optional string product_model = 7;
      {PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.product_model_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // optional string build_version_sdk_full = 8;
      {PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.build_version_sdk_full_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // optional string given_name = 9;
      {PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.given_name_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // optional string serial = 10;
      {PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.serial_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // optional string mdns_service_version = 11;
      {PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.mdns_service_version_), _Internal::kHasBitsOffset + 9, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // optional string hostname = 12;
      {PROTOBUF_FIELD_OFFSET(MdnsService, _impl_.hostname_), _Internal::kHasBitsOffset + 10, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\25\10\7\6\4\4\0\15\26\12\6\24\10\0\0\0"
      "adb.proto.MdnsService"
      "instance"
      "service"
      "domain"
      "ipv4"
      "ipv6"
      "product_model"
      "build_version_sdk_full"
      "given_name"
      "serial"
      "mdns_service_version"
      "hostname"
    }},
  };
}


inline constexpr MdnsService::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        ipv6_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::adb::proto::MdnsService,
            PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.ipv6_)>()
         }
        ,
        instance_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        service_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        domain_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        ipv4_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        product_model_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        build_version_sdk_full_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        given_name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        serial_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        mdns_service_version_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        hostname_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        port_{0u} {}

template <typename>
constexpr MdnsService::MdnsService(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL MdnsService::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) MdnsService(arena);
}
constexpr auto MdnsService::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(MdnsService), alignof(MdnsService));
}
constexpr auto MdnsService::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &MdnsService::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<MdnsService>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &MdnsService::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<MdnsService>(), &MdnsService::ByteSizeLong,
              &MdnsService::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(MdnsService, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[7],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_adb_5fhost_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct MdnsServiceGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr MdnsServiceGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 MdnsService_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(MdnsService::InternalGenerateClassData_(
            _default, &MdnsService_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<MdnsService>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~MdnsServiceGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) MdnsService _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<MdnsService>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(MdnsServiceGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST MdnsServiceGlobalsTypeInternal MdnsService_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* MdnsService_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return MdnsService_globals_.GetClassData();
#else
  return MdnsService_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class Device::_Internal {
 public:
  using HasBits = decltype(::std::declval<Device>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Device, _impl_._has_bits_);
};

constexpr Device::ParseTableT_ Device::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(Device, _impl_._has_bits_),
      0, // no _extensions_
      10, 120,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294966272,  // skipmap
      offsetof(ParseTableT_, field_entries),
      10,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::adb::proto::Device>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string serial = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.serial_)}},
      // .adb.proto.ConnectionState state = 2;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Device, _impl_.state_), 5>(),
       {16, 5, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.state_)}},
      // string bus_address = 3;
      {::_pbi::TcParser::FastUS1,
       {26, 1, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.bus_address_)}},
      // string product = 4;
      {::_pbi::TcParser::FastUS1,
       {34, 2, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.product_)}},
      // string model = 5;
      {::_pbi::TcParser::FastUS1,
       {42, 3, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.model_)}},
      // string device = 6;
      {::_pbi::TcParser::FastUS1,
       {50, 4, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.device_)}},
      // .adb.proto.ConnectionType connection_type = 7;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(Device, _impl_.connection_type_), 6>(),
       {56, 6, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.connection_type_)}},
      // int64 negotiated_speed = 8;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Device, _impl_.negotiated_speed_), 7>(),
       {64, 7, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.negotiated_speed_)}},
      // int64 max_speed = 9;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Device, _impl_.max_speed_), 8>(),
       {72, 8, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.max_speed_)}},
      // int64 transport_id = 10;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(Device, _impl_.transport_id_), 9>(),
       {80, 9, 0,
        PROTOBUF_FIELD_OFFSET(Device, _impl_.transport_id_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // string serial = 1;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.serial_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .adb.proto.ConnectionState state = 2;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.state_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // string bus_address = 3;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.bus_address_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string product = 4;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.product_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string model = 5;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.model_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string device = 6;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.device_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .adb.proto.ConnectionType connection_type = 7;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.connection_type_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // int64 negotiated_speed = 8;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.negotiated_speed_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // int64 max_speed = 9;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.max_speed_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // int64 transport_id = 10;
      {PROTOBUF_FIELD_OFFSET(Device, _impl_.transport_id_), _Internal::kHasBitsOffset + 9, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    }},
    // no aux_entries
    {{
      "\20\6\0\13\7\5\6\0\0\0\0\0\0\0\0\0"
      "adb.proto.Device"
      "serial"
      "bus_address"
      "product"
      "model"
      "device"
    }},
  };
}


inline constexpr Device::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        serial_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        bus_address_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        product_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        model_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        device_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        state_{static_cast< ::adb::proto::ConnectionState >(0)},
        connection_type_{static_cast< ::adb::proto::ConnectionType >(0)},
        negotiated_speed_{::int64_t{0}},
        max_speed_{::int64_t{0}},
        transport_id_{::int64_t{0}} {}

template <typename>
constexpr Device::Device(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL Device::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Device(arena);
}
constexpr auto Device::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Device), alignof(Device));
}
constexpr auto Device::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &Device::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Device>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Device::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Device>(), &Device::ByteSizeLong,
              &Device::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Device, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[0],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_adb_5fhost_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct DeviceGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr DeviceGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 Device_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(Device::InternalGenerateClassData_(
            _default, &Device_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<Device>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~DeviceGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) Device _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<Device>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(DeviceGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST DeviceGlobalsTypeInternal Device_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* Device_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return Device_globals_.GetClassData();
#else
  return Device_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class AdbServerStatus::_Internal {
 public:
  using HasBits = decltype(::std::declval<AdbServerStatus>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_._has_bits_);
};

constexpr AdbServerStatus::ParseTableT_ AdbServerStatus::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_._has_bits_),
      0, // no _extensions_
      14, 120,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294950912,  // skipmap
      offsetof(ParseTableT_, field_entries),
      14,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::adb::proto::AdbServerStatus>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // .adb.proto.AdbServerStatus.UsbBackend usb_backend = 1;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(AdbServerStatus, _impl_.usb_backend_), 8>(),
       {8, 8, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.usb_backend_)}},
      // bool usb_backend_forced = 2;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(AdbServerStatus, _impl_.usb_backend_forced_), 10>(),
       {16, 10, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.usb_backend_forced_)}},
      // .adb.proto.AdbServerStatus.MdnsBackend mdns_backend = 3;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(AdbServerStatus, _impl_.mdns_backend_), 9>(),
       {24, 9, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.mdns_backend_)}},
      // bool mdns_backend_forced = 4;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(AdbServerStatus, _impl_.mdns_backend_forced_), 11>(),
       {32, 11, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.mdns_backend_forced_)}},
      // string version = 5;
      {::_pbi::TcParser::FastUS1,
       {42, 0, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.version_)}},
      // string build = 6;
      {::_pbi::TcParser::FastUS1,
       {50, 1, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.build_)}},
      // string executable_absolute_path = 7;
      {::_pbi::TcParser::FastUS1,
       {58, 2, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.executable_absolute_path_)}},
      // string log_absolute_path = 8;
      {::_pbi::TcParser::FastUS1,
       {66, 3, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.log_absolute_path_)}},
      // string os = 9;
      {::_pbi::TcParser::FastUS1,
       {74, 4, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.os_)}},
      // optional string trace_level = 10;
      {::_pbi::TcParser::FastUS1,
       {82, 5, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.trace_level_)}},
      // optional bool burst_mode = 11;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(AdbServerStatus, _impl_.burst_mode_), 12>(),
       {88, 12, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.burst_mode_)}},
      // optional bool mdns_enabled = 12;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(AdbServerStatus, _impl_.mdns_enabled_), 13>(),
       {96, 13, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.mdns_enabled_)}},
      // optional string keystore_path = 13;
      {::_pbi::TcParser::FastUS1,
       {106, 6, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.keystore_path_)}},
      // optional string known_hosts_path = 14;
      {::_pbi::TcParser::FastUS1,
       {114, 7, 0,
        PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.known_hosts_path_)}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // .adb.proto.AdbServerStatus.UsbBackend usb_backend = 1;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.usb_backend_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // bool usb_backend_forced = 2;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.usb_backend_forced_), _Internal::kHasBitsOffset + 10, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // .adb.proto.AdbServerStatus.MdnsBackend mdns_backend = 3;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.mdns_backend_), _Internal::kHasBitsOffset + 9, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // bool mdns_backend_forced = 4;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.mdns_backend_forced_), _Internal::kHasBitsOffset + 11, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // string version = 5;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.version_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string build = 6;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.build_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string executable_absolute_path = 7;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.executable_absolute_path_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string log_absolute_path = 8;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.log_absolute_path_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string os = 9;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.os_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // optional string trace_level = 10;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.trace_level_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // optional bool burst_mode = 11;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.burst_mode_), _Internal::kHasBitsOffset + 12, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // optional bool mdns_enabled = 12;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.mdns_enabled_), _Internal::kHasBitsOffset + 13, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // optional string keystore_path = 13;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.keystore_path_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // optional string known_hosts_path = 14;
      {PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.known_hosts_path_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\31\0\0\0\0\7\5\30\21\2\13\0\0\15\20\0"
      "adb.proto.AdbServerStatus"
      "version"
      "build"
      "executable_absolute_path"
      "log_absolute_path"
      "os"
      "trace_level"
      "keystore_path"
      "known_hosts_path"
    }},
  };
}


inline constexpr AdbServerStatus::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        version_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        build_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        executable_absolute_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        log_absolute_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        os_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        trace_level_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        keystore_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        known_hosts_path_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        usb_backend_{static_cast< ::adb::proto::AdbServerStatus_UsbBackend >(0)},
        mdns_backend_{static_cast< ::adb::proto::AdbServerStatus_MdnsBackend >(0)},
        usb_backend_forced_{false},
        mdns_backend_forced_{false},
        burst_mode_{false},
        mdns_enabled_{false} {}

template <typename>
constexpr AdbServerStatus::AdbServerStatus(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL AdbServerStatus::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) AdbServerStatus(arena);
}
constexpr auto AdbServerStatus::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(AdbServerStatus), alignof(AdbServerStatus));
}
constexpr auto AdbServerStatus::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &AdbServerStatus::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<AdbServerStatus>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &AdbServerStatus::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<AdbServerStatus>(), &AdbServerStatus::ByteSizeLong,
              &AdbServerStatus::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[2],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_adb_5fhost_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct AdbServerStatusGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr AdbServerStatusGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 AdbServerStatus_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(AdbServerStatus::InternalGenerateClassData_(
            _default, &AdbServerStatus_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<AdbServerStatus>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~AdbServerStatusGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) AdbServerStatus _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<AdbServerStatus>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(AdbServerStatusGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST AdbServerStatusGlobalsTypeInternal AdbServerStatus_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* AdbServerStatus_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return AdbServerStatus_globals_.GetClassData();
#else
  return AdbServerStatus_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class ServiceAdbTls::_Internal {
 public:
  using HasBits = decltype(::std::declval<ServiceAdbTls>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ServiceAdbTls, _impl_._has_bits_);
};

constexpr ServiceAdbTls::ParseTableT_ ServiceAdbTls::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ServiceAdbTls, _impl_._has_bits_),
      0, // no _extensions_
      2, 8,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967292,  // skipmap
      offsetof(ParseTableT_, field_entries),
      2,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::adb::proto::ServiceAdbTls>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // bool known_device = 2;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(ServiceAdbTls, _impl_.known_device_), 1>(),
       {16, 1, 0,
        PROTOBUF_FIELD_OFFSET(ServiceAdbTls, _impl_.known_device_)}},
      // .adb.proto.MdnsService service = 1;
      {::_pbi::TcParser::FastMtS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(ServiceAdbTls, _impl_.service_)}},
    }}, {{
      65535, 65535
    }}, {{
      // .adb.proto.MdnsService service = 1;
      {PROTOBUF_FIELD_OFFSET(ServiceAdbTls, _impl_.service_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // bool known_device = 2;
      {PROTOBUF_FIELD_OFFSET(ServiceAdbTls, _impl_.known_device_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::adb::proto::MdnsService>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::adb::proto::MdnsService_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr ServiceAdbTls::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        service_{nullptr},
        known_device_{false} {}

template <typename>
constexpr ServiceAdbTls::ServiceAdbTls(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ServiceAdbTls::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ServiceAdbTls(arena);
}
constexpr auto ServiceAdbTls::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(ServiceAdbTls), alignof(ServiceAdbTls));
}
constexpr auto ServiceAdbTls::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ServiceAdbTls::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ServiceAdbTls>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ServiceAdbTls::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ServiceAdbTls>(), &ServiceAdbTls::ByteSizeLong,
              &ServiceAdbTls::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ServiceAdbTls, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[5],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_adb_5fhost_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ServiceAdbTlsGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ServiceAdbTlsGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ServiceAdbTls_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ServiceAdbTls::InternalGenerateClassData_(
            _default, &ServiceAdbTls_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ServiceAdbTls>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ServiceAdbTlsGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ServiceAdbTls _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ServiceAdbTls>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ServiceAdbTlsGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ServiceAdbTlsGlobalsTypeInternal ServiceAdbTls_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ServiceAdbTls_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ServiceAdbTls_globals_.GetClassData();
#else
  return ServiceAdbTls_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class ServiceAdbTcp::_Internal {
 public:
  using HasBits = decltype(::std::declval<ServiceAdbTcp>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ServiceAdbTcp, _impl_._has_bits_);
};

constexpr ServiceAdbTcp::ParseTableT_ ServiceAdbTcp::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ServiceAdbTcp, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::adb::proto::ServiceAdbTcp>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // .adb.proto.MdnsService service = 1;
      {::_pbi::TcParser::FastMtS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(ServiceAdbTcp, _impl_.service_)}},
    }}, {{
      65535, 65535
    }}, {{
      // .adb.proto.MdnsService service = 1;
      {PROTOBUF_FIELD_OFFSET(ServiceAdbTcp, _impl_.service_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::adb::proto::MdnsService>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::adb::proto::MdnsService_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr ServiceAdbTcp::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        service_{nullptr} {}

template <typename>
constexpr ServiceAdbTcp::ServiceAdbTcp(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ServiceAdbTcp::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ServiceAdbTcp(arena);
}
constexpr auto ServiceAdbTcp::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(ServiceAdbTcp), alignof(ServiceAdbTcp));
}
constexpr auto ServiceAdbTcp::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ServiceAdbTcp::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ServiceAdbTcp>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ServiceAdbTcp::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ServiceAdbTcp>(), &ServiceAdbTcp::ByteSizeLong,
              &ServiceAdbTcp::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ServiceAdbTcp, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[4],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_adb_5fhost_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ServiceAdbTcpGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ServiceAdbTcpGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ServiceAdbTcp_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ServiceAdbTcp::InternalGenerateClassData_(
            _default, &ServiceAdbTcp_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ServiceAdbTcp>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ServiceAdbTcpGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ServiceAdbTcp _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ServiceAdbTcp>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ServiceAdbTcpGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ServiceAdbTcpGlobalsTypeInternal ServiceAdbTcp_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ServiceAdbTcp_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ServiceAdbTcp_globals_.GetClassData();
#else
  return ServiceAdbTcp_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class ServiceAdbPairing::_Internal {
 public:
  using HasBits = decltype(::std::declval<ServiceAdbPairing>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ServiceAdbPairing, _impl_._has_bits_);
};

constexpr ServiceAdbPairing::ParseTableT_ ServiceAdbPairing::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ServiceAdbPairing, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::adb::proto::ServiceAdbPairing>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // .adb.proto.MdnsService service = 1;
      {::_pbi::TcParser::FastMtS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(ServiceAdbPairing, _impl_.service_)}},
    }}, {{
      65535, 65535
    }}, {{
      // .adb.proto.MdnsService service = 1;
      {PROTOBUF_FIELD_OFFSET(ServiceAdbPairing, _impl_.service_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::adb::proto::MdnsService>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::adb::proto::MdnsService_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr ServiceAdbPairing::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        service_{nullptr} {}

template <typename>
constexpr ServiceAdbPairing::ServiceAdbPairing(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ServiceAdbPairing::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ServiceAdbPairing(arena);
}
constexpr auto ServiceAdbPairing::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(ServiceAdbPairing), alignof(ServiceAdbPairing));
}
constexpr auto ServiceAdbPairing::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ServiceAdbPairing::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ServiceAdbPairing>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ServiceAdbPairing::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ServiceAdbPairing>(), &ServiceAdbPairing::ByteSizeLong,
              &ServiceAdbPairing::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ServiceAdbPairing, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[6],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_adb_5fhost_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ServiceAdbPairingGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ServiceAdbPairingGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ServiceAdbPairing_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ServiceAdbPairing::InternalGenerateClassData_(
            _default, &ServiceAdbPairing_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ServiceAdbPairing>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ServiceAdbPairingGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ServiceAdbPairing _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ServiceAdbPairing>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ServiceAdbPairingGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ServiceAdbPairingGlobalsTypeInternal ServiceAdbPairing_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ServiceAdbPairing_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ServiceAdbPairing_globals_.GetClassData();
#else
  return ServiceAdbPairing_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class Devices::_Internal {
 public:
  using HasBits = decltype(::std::declval<Devices>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Devices, _impl_._has_bits_);
};

constexpr Devices::ParseTableT_ Devices::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(Devices, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::adb::proto::Devices>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // repeated .adb.proto.Device device = 1;
      {::_pbi::TcParser::FastMtR1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(Devices, _impl_.device_)}},
    }}, {{
      65535, 65535
    }}, {{
      // repeated .adb.proto.Device device = 1;
      {PROTOBUF_FIELD_OFFSET(Devices, _impl_.device_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::adb::proto::Device>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::adb::proto::Device_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr Devices::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        device_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::adb::proto::Devices,
            PROTOBUF_FIELD_OFFSET(::adb::proto::Devices, _impl_.device_)>()
         }
     {}

template <typename>
constexpr Devices::Devices(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL Devices::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Devices(arena);
}
constexpr auto Devices::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(Devices), alignof(Devices));
}
constexpr auto Devices::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &Devices::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Devices>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Devices::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Devices>(), &Devices::ByteSizeLong,
              &Devices::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Devices, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[1],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_adb_5fhost_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct DevicesGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr DevicesGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 Devices_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(Devices::InternalGenerateClassData_(
            _default, &Devices_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<Devices>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~DevicesGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) Devices _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<Devices>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(DevicesGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST DevicesGlobalsTypeInternal Devices_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* Devices_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return Devices_globals_.GetClassData();
#else
  return Devices_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class MdnsServices::_Internal {
 public:
  using HasBits = decltype(::std::declval<MdnsServices>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(MdnsServices, _impl_._has_bits_);
};

constexpr MdnsServices::ParseTableT_ MdnsServices::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(MdnsServices, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      3,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::adb::proto::MdnsServices>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // repeated .adb.proto.ServiceAdbTcp tcp = 1;
      {::_pbi::TcParser::FastMtR1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(MdnsServices, _impl_.tcp_)}},
      // repeated .adb.proto.ServiceAdbTls tls = 2;
      {::_pbi::TcParser::FastMtR1,
       {18, 1, 1,
        PROTOBUF_FIELD_OFFSET(MdnsServices, _impl_.tls_)}},
      // repeated .adb.proto.ServiceAdbPairing pair = 3;
      {::_pbi::TcParser::FastMtR1,
       {26, 2, 2,
        PROTOBUF_FIELD_OFFSET(MdnsServices, _impl_.pair_)}},
    }}, {{
      65535, 65535
    }}, {{
      // repeated .adb.proto.ServiceAdbTcp tcp = 1;
      {PROTOBUF_FIELD_OFFSET(MdnsServices, _impl_.tcp_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated .adb.proto.ServiceAdbTls tls = 2;
      {PROTOBUF_FIELD_OFFSET(MdnsServices, _impl_.tls_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated .adb.proto.ServiceAdbPairing pair = 3;
      {PROTOBUF_FIELD_OFFSET(MdnsServices, _impl_.pair_), _Internal::kHasBitsOffset + 2, 2, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::adb::proto::ServiceAdbTcp>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::adb::proto::ServiceAdbTcp_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::adb::proto::ServiceAdbTls>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::adb::proto::ServiceAdbTls_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::adb::proto::ServiceAdbPairing>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::adb::proto::ServiceAdbPairing_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr MdnsServices::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        tcp_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::adb::proto::MdnsServices,
            PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsServices, _impl_.tcp_)>()
         }
        ,
        tls_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::adb::proto::MdnsServices,
            PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsServices, _impl_.tls_)>()
         }
        ,
        pair_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::adb::proto::MdnsServices,
            PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsServices, _impl_.pair_)>()
         }
     {}

template <typename>
constexpr MdnsServices::MdnsServices(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL MdnsServices::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) MdnsServices(arena);
}
constexpr auto MdnsServices::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(MdnsServices), alignof(MdnsServices));
}
constexpr auto MdnsServices::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &MdnsServices::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<MdnsServices>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &MdnsServices::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<MdnsServices>(), &MdnsServices::ByteSizeLong,
              &MdnsServices::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(MdnsServices, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[3],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_adb_5fhost_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct MdnsServicesGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr MdnsServicesGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 MdnsServices_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(MdnsServices::InternalGenerateClassData_(
            _default, &MdnsServices_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<MdnsServices>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~MdnsServicesGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) MdnsServices _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<MdnsServices>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(MdnsServicesGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST MdnsServicesGlobalsTypeInternal MdnsServices_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* MdnsServices_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return MdnsServices_globals_.GetClassData();
#else
  return MdnsServices_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
}  // namespace proto
}  // namespace adb
static const ::_pb::EnumDescriptor* PROTOBUF_NONNULL
    file_level_enum_descriptors_adb_5fhost_2eproto[4];
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_adb_5fhost_2eproto = nullptr;
const ::uint32_t
    TableStruct_adb_5fhost_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_._has_bits_),
        13, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.serial_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.state_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.bus_address_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.product_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.model_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.device_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.connection_type_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.negotiated_speed_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.max_speed_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::Device, _impl_.transport_id_),
        0,
        5,
        1,
        2,
        3,
        4,
        6,
        7,
        8,
        9,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::adb::proto::Devices, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::adb::proto::Devices, _impl_.device_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_._has_bits_),
        17, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.usb_backend_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.usb_backend_forced_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.mdns_backend_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.mdns_backend_forced_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.version_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.build_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.executable_absolute_path_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.log_absolute_path_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.os_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.trace_level_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.burst_mode_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.mdns_enabled_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.keystore_path_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::AdbServerStatus, _impl_.known_hosts_path_),
        8,
        10,
        9,
        11,
        0,
        1,
        2,
        3,
        4,
        5,
        12,
        13,
        6,
        7,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsServices, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsServices, _impl_.tcp_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsServices, _impl_.tls_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsServices, _impl_.pair_),
        0,
        1,
        2,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::adb::proto::ServiceAdbTcp, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::adb::proto::ServiceAdbTcp, _impl_.service_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::adb::proto::ServiceAdbTls, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::adb::proto::ServiceAdbTls, _impl_.service_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::ServiceAdbTls, _impl_.known_device_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::adb::proto::ServiceAdbPairing, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::adb::proto::ServiceAdbPairing, _impl_.service_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_._has_bits_),
        15, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.instance_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.service_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.domain_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.ipv4_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.ipv6_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.port_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.product_model_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.build_version_sdk_full_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.given_name_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.serial_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.mdns_service_version_),
        PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.hostname_),
        1,
        2,
        3,
        4,
        0,
        11,
        5,
        6,
        7,
        8,
        9,
        10,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::adb::proto::Device)},
        {23, sizeof(::adb::proto::Devices)},
        {28, sizeof(::adb::proto::AdbServerStatus)},
        {59, sizeof(::adb::proto::MdnsServices)},
        {68, sizeof(::adb::proto::ServiceAdbTcp)},
        {73, sizeof(::adb::proto::ServiceAdbTls)},
        {80, sizeof(::adb::proto::ServiceAdbPairing)},
        {85, sizeof(::adb::proto::MdnsService)},
};
static const ::_pbi::MessageGlobalsBase* PROTOBUF_NONNULL const
    file_message_globals[] = {
        &::adb::proto::Device_globals_,
        &::adb::proto::Devices_globals_,
        &::adb::proto::AdbServerStatus_globals_,
        &::adb::proto::MdnsServices_globals_,
        &::adb::proto::ServiceAdbTcp_globals_,
        &::adb::proto::ServiceAdbTls_globals_,
        &::adb::proto::ServiceAdbPairing_globals_,
        &::adb::proto::MdnsService_globals_,
};
const char descriptor_table_protodef_adb_5fhost_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n\016adb_host.proto\022\tadb.proto\"\377\001\n\006Device\022\016"
    "\n\006serial\030\001 \001(\t\022)\n\005state\030\002 \001(\0162\032.adb.prot"
    "o.ConnectionState\022\023\n\013bus_address\030\003 \001(\t\022\017"
    "\n\007product\030\004 \001(\t\022\r\n\005model\030\005 \001(\t\022\016\n\006device"
    "\030\006 \001(\t\0222\n\017connection_type\030\007 \001(\0162\031.adb.pr"
    "oto.ConnectionType\022\030\n\020negotiated_speed\030\010"
    " \001(\003\022\021\n\tmax_speed\030\t \001(\003\022\024\n\014transport_id\030"
    "\n \001(\003\",\n\007Devices\022!\n\006device\030\001 \003(\0132\021.adb.p"
    "roto.Device\"\267\005\n\017AdbServerStatus\022:\n\013usb_b"
    "ackend\030\001 \001(\0162%.adb.proto.AdbServerStatus"
    ".UsbBackend\022\032\n\022usb_backend_forced\030\002 \001(\010\022"
    "<\n\014mdns_backend\030\003 \001(\0162&.adb.proto.AdbSer"
    "verStatus.MdnsBackend\022\033\n\023mdns_backend_fo"
    "rced\030\004 \001(\010\022\017\n\007version\030\005 \001(\t\022\r\n\005build\030\006 \001"
    "(\t\022 \n\030executable_absolute_path\030\007 \001(\t\022\031\n\021"
    "log_absolute_path\030\010 \001(\t\022\n\n\002os\030\t \001(\t\022\030\n\013t"
    "race_level\030\n \001(\tH\000\210\001\001\022\027\n\nburst_mode\030\013 \001("
    "\010H\001\210\001\001\022\031\n\014mdns_enabled\030\014 \001(\010H\002\210\001\001\022\032\n\rkey"
    "store_path\030\r \001(\tH\003\210\001\001\022\035\n\020known_hosts_pat"
    "h\030\016 \001(\tH\004\210\001\001\"G\n\nUsbBackend\022\017\n\013UNKNOWN_US"
    "B\020\000\022\n\n\006NATIVE\020\001\022\n\n\006LIBUSB\020\002\022\020\n\014USB_DISAB"
    "LED\020\003\"_\n\013MdnsBackend\022\020\n\014UNKNOWN_MDNS\020\000\022\013"
    "\n\007BONJOUR\020\001\022\016\n\nOPENSCREEN\020\002\022\016\n\nLIBADBMDN"
    "S\020\003\022\021\n\rMDNS_DISABLED\020\004B\016\n\014_trace_levelB\r"
    "\n\013_burst_modeB\017\n\r_mdns_enabledB\020\n\016_keyst"
    "ore_pathB\023\n\021_known_hosts_path\"\210\001\n\014MdnsSe"
    "rvices\022%\n\003tcp\030\001 \003(\0132\030.adb.proto.ServiceA"
    "dbTcp\022%\n\003tls\030\002 \003(\0132\030.adb.proto.ServiceAd"
    "bTls\022*\n\004pair\030\003 \003(\0132\034.adb.proto.ServiceAd"
    "bPairing\"8\n\rServiceAdbTcp\022\'\n\007service\030\001 \001"
    "(\0132\026.adb.proto.MdnsService\"N\n\rServiceAdb"
    "Tls\022\'\n\007service\030\001 \001(\0132\026.adb.proto.MdnsSer"
    "vice\022\024\n\014known_device\030\002 \001(\010\"<\n\021ServiceAdb"
    "Pairing\022\'\n\007service\030\001 \001(\0132\026.adb.proto.Mdn"
    "sService\"\216\003\n\013MdnsService\022\020\n\010instance\030\001 \001"
    "(\t\022\017\n\007service\030\002 \001(\t\022\016\n\006domain\030\003 \001(\t\022\021\n\004i"
    "pv4\030\004 \001(\tH\000\210\001\001\022\014\n\004ipv6\030\005 \003(\t\022\014\n\004port\030\006 \001"
    "(\r\022\032\n\rproduct_model\030\007 \001(\tH\001\210\001\001\022#\n\026build_"
    "version_sdk_full\030\010 \001(\tH\002\210\001\001\022\027\n\ngiven_nam"
    "e\030\t \001(\tH\003\210\001\001\022\023\n\006serial\030\n \001(\tH\004\210\001\001\022!\n\024mdn"
    "s_service_version\030\013 \001(\tH\005\210\001\001\022\025\n\010hostname"
    "\030\014 \001(\tH\006\210\001\001B\007\n\005_ipv4B\020\n\016_product_modelB\031"
    "\n\027_build_version_sdk_fullB\r\n\013_given_name"
    "B\t\n\007_serialB\027\n\025_mdns_service_versionB\013\n\t"
    "_hostname*\310\001\n\017ConnectionState\022\007\n\003ANY\020\000\022\016"
    "\n\nCONNECTING\020\001\022\017\n\013AUTHORIZING\020\002\022\020\n\014UNAUT"
    "HORIZED\020\003\022\020\n\014NOPERMISSION\020\004\022\014\n\010DETACHED\020"
    "\005\022\013\n\007OFFLINE\020\006\022\016\n\nBOOTLOADER\020\007\022\n\n\006DEVICE"
    "\020\010\022\010\n\004HOST\020\t\022\014\n\010RECOVERY\020\n\022\014\n\010SIDELOAD\020\013"
    "\022\n\n\006RESCUE\020\014*2\n\016ConnectionType\022\013\n\007UNKNOW"
    "N\020\000\022\007\n\003USB\020\001\022\n\n\006SOCKET\020\002B-\n\035com.android."
    "server.adb.protosB\014DevicesProtob\006proto3"
};
static ::absl::once_flag descriptor_table_adb_5fhost_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_adb_5fhost_2eproto = {
    false,
    false,
    2079,
    descriptor_table_protodef_adb_5fhost_2eproto,
    "adb_host.proto",
    &descriptor_table_adb_5fhost_2eproto_once,
    nullptr,
    0,
    8,
    schemas,
    file_message_globals,
    TableStruct_adb_5fhost_2eproto::offsets,
    file_level_enum_descriptors_adb_5fhost_2eproto,
    file_level_service_descriptors_adb_5fhost_2eproto,
};
namespace adb {
namespace proto {
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
AdbServerStatus_UsbBackend_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_adb_5fhost_2eproto);
  return file_level_enum_descriptors_adb_5fhost_2eproto[0];
}
PROTOBUF_CONSTINIT const uint32_t AdbServerStatus_UsbBackend_internal_data_[] = {
    262144u, 0u, };
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
AdbServerStatus_MdnsBackend_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_adb_5fhost_2eproto);
  return file_level_enum_descriptors_adb_5fhost_2eproto[1];
}
PROTOBUF_CONSTINIT const uint32_t AdbServerStatus_MdnsBackend_internal_data_[] = {
    327680u, 0u, };
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
ConnectionState_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_adb_5fhost_2eproto);
  return file_level_enum_descriptors_adb_5fhost_2eproto[2];
}
PROTOBUF_CONSTINIT const uint32_t ConnectionState_internal_data_[] = {
    851968u, 0u, };
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
ConnectionType_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_adb_5fhost_2eproto);
  return file_level_enum_descriptors_adb_5fhost_2eproto[3];
}
PROTOBUF_CONSTINIT const uint32_t ConnectionType_internal_data_[] = {
    196608u, 0u, };
// ===================================================================

Device::Device(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Device_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:adb.proto.Device)
}
PROTOBUF_NDEBUG_INLINE Device::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::adb::proto::Device& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        serial_(arena, from.serial_),
        bus_address_(arena, from.bus_address_),
        product_(arena, from.product_),
        model_(arena, from.model_),
        device_(arena, from.device_) {}

Device::Device(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Device& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Device_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Device* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, state_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, state_),
           offsetof(Impl_, transport_id_) -
               offsetof(Impl_, state_) +
               sizeof(Impl_::transport_id_));

  // @@protoc_insertion_point(copy_constructor:adb.proto.Device)
}
PROTOBUF_NDEBUG_INLINE Device::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        serial_(arena),
        bus_address_(arena),
        product_(arena),
        model_(arena),
        device_(arena) {}

inline void Device::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, state_),
           0,
           offsetof(Impl_, transport_id_) -
               offsetof(Impl_, state_) +
               sizeof(Impl_::transport_id_));
}
Device::~Device() {
  // @@protoc_insertion_point(destructor:adb.proto.Device)
  SharedDtor(*this);
}
inline void Device::SharedDtor(MessageLite& self) {
  Device& this_ = static_cast<Device&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.serial_.Destroy();
  this_._impl_.bus_address_.Destroy();
  this_._impl_.product_.Destroy();
  this_._impl_.model_.Destroy();
  this_._impl_.device_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Device_class_data_ =
        Device::InternalGenerateClassData_(Device_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Device::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Device_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Device_class_data_.tc_table);
  return Device_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Device::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Device_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&Device_globals_));
  return Device_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const Device::ParseTableT_
    Device::_table_ =
        Device::InternalGenerateParseTable_(Device_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void Device::Clear() {
// @@protoc_insertion_point(message_clear_start:adb.proto.Device)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.serial_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.bus_address_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.product_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.model_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _impl_.device_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000e0U)) {
    ::memset(&_impl_.state_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.negotiated_speed_) -
        reinterpret_cast<char*>(&_impl_.state_)) + sizeof(_impl_.negotiated_speed_));
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    ::memset(&_impl_.max_speed_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.transport_id_) -
        reinterpret_cast<char*>(&_impl_.max_speed_)) + sizeof(_impl_.transport_id_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Device::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Device& this_ = static_cast<const Device&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Device::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Device& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:adb.proto.Device)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string serial = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_serial().empty()) {
      const ::std::string& _s = this_._internal_serial();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.Device.serial");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // .adb.proto.ConnectionState state = 2;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_state() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          2, this_._internal_state(), target);
    }
  }

  // string bus_address = 3;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_bus_address().empty()) {
      const ::std::string& _s = this_._internal_bus_address();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.Device.bus_address");
      target = stream->WriteStringMaybeAliased(3, _s, target);
    }
  }

  // string product = 4;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_product().empty()) {
      const ::std::string& _s = this_._internal_product();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.Device.product");
      target = stream->WriteStringMaybeAliased(4, _s, target);
    }
  }

  // string model = 5;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (!this_._internal_model().empty()) {
      const ::std::string& _s = this_._internal_model();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.Device.model");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // string device = 6;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (!this_._internal_device().empty()) {
      const ::std::string& _s = this_._internal_device();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.Device.device");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  // .adb.proto.ConnectionType connection_type = 7;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_connection_type() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          7, this_._internal_connection_type(), target);
    }
  }

  // int64 negotiated_speed = 8;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_negotiated_speed() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<8>(
              stream, this_._internal_negotiated_speed(), target);
    }
  }

  // int64 max_speed = 9;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (this_._internal_max_speed() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<9>(
              stream, this_._internal_max_speed(), target);
    }
  }

  // int64 transport_id = 10;
  if (CheckHasBit(cached_has_bits, 0x00000200U)) {
    if (this_._internal_transport_id() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<10>(
              stream, this_._internal_transport_id(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:adb.proto.Device)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Device::ByteSizeLong(const MessageLite& base) {
  const Device& this_ = static_cast<const Device&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Device::ByteSizeLong() const {
  const Device& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:adb.proto.Device)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // string serial = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_serial().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_serial());
      }
    }
    // string bus_address = 3;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_bus_address().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_bus_address());
      }
    }
    // string product = 4;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_product().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_product());
      }
    }
    // string model = 5;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!this_._internal_model().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_model());
      }
    }
    // string device = 6;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!this_._internal_device().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_device());
      }
    }
    // .adb.proto.ConnectionState state = 2;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_state() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_state());
      }
    }
    // .adb.proto.ConnectionType connection_type = 7;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_connection_type() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_connection_type());
      }
    }
    // int64 negotiated_speed = 8;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_negotiated_speed() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_negotiated_speed());
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    // int64 max_speed = 9;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (this_._internal_max_speed() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_max_speed());
      }
    }
    // int64 transport_id = 10;
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (this_._internal_transport_id() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_transport_id());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Device::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<Device*>(&to_msg);
  auto& from = static_cast<const Device&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:adb.proto.Device)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_serial().empty()) {
        _this->_internal_set_serial(from._internal_serial());
      } else {
        if (_this->_impl_.serial_.IsDefault()) {
          _this->_internal_set_serial("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_bus_address().empty()) {
        _this->_internal_set_bus_address(from._internal_bus_address());
      } else {
        if (_this->_impl_.bus_address_.IsDefault()) {
          _this->_internal_set_bus_address("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_product().empty()) {
        _this->_internal_set_product(from._internal_product());
      } else {
        if (_this->_impl_.product_.IsDefault()) {
          _this->_internal_set_product("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!from._internal_model().empty()) {
        _this->_internal_set_model(from._internal_model());
      } else {
        if (_this->_impl_.model_.IsDefault()) {
          _this->_internal_set_model("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!from._internal_device().empty()) {
        _this->_internal_set_device(from._internal_device());
      } else {
        if (_this->_impl_.device_.IsDefault()) {
          _this->_internal_set_device("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_state() != 0) {
        _this->_impl_.state_ = from._impl_.state_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_connection_type() != 0) {
        _this->_impl_.connection_type_ = from._impl_.connection_type_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_negotiated_speed() != 0) {
        _this->_impl_.negotiated_speed_ = from._impl_.negotiated_speed_;
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (from._internal_max_speed() != 0) {
        _this->_impl_.max_speed_ = from._impl_.max_speed_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (from._internal_transport_id() != 0) {
        _this->_impl_.transport_id_ = from._impl_.transport_id_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Device::CopyFrom(const Device& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:adb.proto.Device)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Device::InternalSwap(Device* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.serial_, &other->_impl_.serial_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.bus_address_, &other->_impl_.bus_address_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.product_, &other->_impl_.product_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.model_, &other->_impl_.model_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.device_, &other->_impl_.device_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Device, _impl_.transport_id_)
      + sizeof(Device::_impl_.transport_id_)
      - PROTOBUF_FIELD_OFFSET(Device, _impl_.state_)>(
          reinterpret_cast<char*>(&_impl_.state_),
          reinterpret_cast<char*>(&other->_impl_.state_));
}

::google::protobuf::Metadata Device::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

Devices::Devices(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Devices_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:adb.proto.Devices)
}
PROTOBUF_NDEBUG_INLINE Devices::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::adb::proto::Devices& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        device_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::adb::proto::Devices,
              PROTOBUF_FIELD_OFFSET(::adb::proto::Devices, _impl_.device_)>()
          , from.device_
        }
     {}

Devices::Devices(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Devices& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Devices_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Devices* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:adb.proto.Devices)
}
PROTOBUF_NDEBUG_INLINE Devices::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        device_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::adb::proto::Devices,
            PROTOBUF_FIELD_OFFSET(::adb::proto::Devices, _impl_.device_)>()
         }
     {}

inline void Devices::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
Devices::~Devices() {
  // @@protoc_insertion_point(destructor:adb.proto.Devices)
  SharedDtor(*this);
}
inline void Devices::SharedDtor(MessageLite& self) {
  Devices& this_ = static_cast<Devices&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Devices_class_data_ =
        Devices::InternalGenerateClassData_(Devices_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Devices::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Devices_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Devices_class_data_.tc_table);
  return Devices_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Devices::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Devices_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&Devices_globals_));
  return Devices_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const Devices::ParseTableT_
    Devices::_table_ =
        Devices::InternalGenerateParseTable_(Devices_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void Devices::Clear() {
// @@protoc_insertion_point(message_clear_start:adb.proto.Devices)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.device_.Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Devices::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Devices& this_ = static_cast<const Devices&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Devices::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Devices& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:adb.proto.Devices)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated .adb.proto.Device device = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_device_size());
         i < n; i++) {
      const auto& repfield = this_._internal_device().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              1, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:adb.proto.Devices)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Devices::ByteSizeLong(const MessageLite& base) {
  const Devices& this_ = static_cast<const Devices&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Devices::ByteSizeLong() const {
  const Devices& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:adb.proto.Devices)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated .adb.proto.Device device = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_device_size();
      for (const auto& msg : this_._internal_device()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Devices::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<Devices*>(&to_msg);
  auto& from = static_cast<const Devices&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:adb.proto.Devices)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _this->_internal_mutable_device()->InternalMergeFromWithArena(
        ::google::protobuf::MessageLite::internal_visibility(), arena,
        from._internal_device());
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Devices::CopyFrom(const Devices& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:adb.proto.Devices)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Devices::InternalSwap(Devices* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.device_.InternalSwap(&other->_impl_.device_);
}

::google::protobuf::Metadata Devices::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

AdbServerStatus::AdbServerStatus(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AdbServerStatus_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:adb.proto.AdbServerStatus)
}
PROTOBUF_NDEBUG_INLINE AdbServerStatus::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::adb::proto::AdbServerStatus& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        version_(arena, from.version_),
        build_(arena, from.build_),
        executable_absolute_path_(arena, from.executable_absolute_path_),
        log_absolute_path_(arena, from.log_absolute_path_),
        os_(arena, from.os_),
        trace_level_(arena, from.trace_level_),
        keystore_path_(arena, from.keystore_path_),
        known_hosts_path_(arena, from.known_hosts_path_) {}

AdbServerStatus::AdbServerStatus(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const AdbServerStatus& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AdbServerStatus_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  AdbServerStatus* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, usb_backend_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, usb_backend_),
           offsetof(Impl_, mdns_enabled_) -
               offsetof(Impl_, usb_backend_) +
               sizeof(Impl_::mdns_enabled_));

  // @@protoc_insertion_point(copy_constructor:adb.proto.AdbServerStatus)
}
PROTOBUF_NDEBUG_INLINE AdbServerStatus::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        version_(arena),
        build_(arena),
        executable_absolute_path_(arena),
        log_absolute_path_(arena),
        os_(arena),
        trace_level_(arena),
        keystore_path_(arena),
        known_hosts_path_(arena) {}

inline void AdbServerStatus::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, usb_backend_),
           0,
           offsetof(Impl_, mdns_enabled_) -
               offsetof(Impl_, usb_backend_) +
               sizeof(Impl_::mdns_enabled_));
}
AdbServerStatus::~AdbServerStatus() {
  // @@protoc_insertion_point(destructor:adb.proto.AdbServerStatus)
  SharedDtor(*this);
}
inline void AdbServerStatus::SharedDtor(MessageLite& self) {
  AdbServerStatus& this_ = static_cast<AdbServerStatus&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.version_.Destroy();
  this_._impl_.build_.Destroy();
  this_._impl_.executable_absolute_path_.Destroy();
  this_._impl_.log_absolute_path_.Destroy();
  this_._impl_.os_.Destroy();
  this_._impl_.trace_level_.Destroy();
  this_._impl_.keystore_path_.Destroy();
  this_._impl_.known_hosts_path_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull AdbServerStatus_class_data_ =
        AdbServerStatus::InternalGenerateClassData_(AdbServerStatus_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AdbServerStatus::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AdbServerStatus_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(AdbServerStatus_class_data_.tc_table);
  return AdbServerStatus_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AdbServerStatus::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AdbServerStatus_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&AdbServerStatus_globals_));
  return AdbServerStatus_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const AdbServerStatus::ParseTableT_
    AdbServerStatus::_table_ =
        AdbServerStatus::InternalGenerateParseTable_(AdbServerStatus_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void AdbServerStatus::Clear() {
// @@protoc_insertion_point(message_clear_start:adb.proto.AdbServerStatus)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.version_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.build_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.executable_absolute_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.log_absolute_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _impl_.os_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _impl_.trace_level_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      _impl_.keystore_path_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      _impl_.known_hosts_path_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00003f00U)) {
    ::memset(&_impl_.usb_backend_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.mdns_enabled_) -
        reinterpret_cast<char*>(&_impl_.usb_backend_)) + sizeof(_impl_.mdns_enabled_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL AdbServerStatus::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const AdbServerStatus& this_ = static_cast<const AdbServerStatus&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL AdbServerStatus::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const AdbServerStatus& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:adb.proto.AdbServerStatus)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .adb.proto.AdbServerStatus.UsbBackend usb_backend = 1;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (this_._internal_usb_backend() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          1, this_._internal_usb_backend(), target);
    }
  }

  // bool usb_backend_forced = 2;
  if (CheckHasBit(cached_has_bits, 0x00000400U)) {
    if (this_._internal_usb_backend_forced() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          2, this_._internal_usb_backend_forced(), target);
    }
  }

  // .adb.proto.AdbServerStatus.MdnsBackend mdns_backend = 3;
  if (CheckHasBit(cached_has_bits, 0x00000200U)) {
    if (this_._internal_mdns_backend() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          3, this_._internal_mdns_backend(), target);
    }
  }

  // bool mdns_backend_forced = 4;
  if (CheckHasBit(cached_has_bits, 0x00000800U)) {
    if (this_._internal_mdns_backend_forced() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          4, this_._internal_mdns_backend_forced(), target);
    }
  }

  // string version = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_version().empty()) {
      const ::std::string& _s = this_._internal_version();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.AdbServerStatus.version");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // string build = 6;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_build().empty()) {
      const ::std::string& _s = this_._internal_build();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.AdbServerStatus.build");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  // string executable_absolute_path = 7;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_executable_absolute_path().empty()) {
      const ::std::string& _s = this_._internal_executable_absolute_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.AdbServerStatus.executable_absolute_path");
      target = stream->WriteStringMaybeAliased(7, _s, target);
    }
  }

  // string log_absolute_path = 8;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (!this_._internal_log_absolute_path().empty()) {
      const ::std::string& _s = this_._internal_log_absolute_path();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.AdbServerStatus.log_absolute_path");
      target = stream->WriteStringMaybeAliased(8, _s, target);
    }
  }

  // string os = 9;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    if (!this_._internal_os().empty()) {
      const ::std::string& _s = this_._internal_os();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.AdbServerStatus.os");
      target = stream->WriteStringMaybeAliased(9, _s, target);
    }
  }

  // optional string trace_level = 10;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    const ::std::string& _s = this_._internal_trace_level();
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
        _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.AdbServerStatus.trace_level");
    target = stream->WriteStringMaybeAliased(10, _s, target);
  }

  // optional bool burst_mode = 11;
  if (CheckHasBit(cached_has_bits, 0x00001000U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        11, this_._internal_burst_mode(), target);
  }

  // optional bool mdns_enabled = 12;
  if (CheckHasBit(cached_has_bits, 0x00002000U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteBoolToArray(
        12, this_._internal_mdns_enabled(), target);
  }

  // optional string keystore_path = 13;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    const ::std::string& _s = this_._internal_keystore_path();
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
        _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.AdbServerStatus.keystore_path");
    target = stream->WriteStringMaybeAliased(13, _s, target);
  }

  // optional string known_hosts_path = 14;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    const ::std::string& _s = this_._internal_known_hosts_path();
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
        _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.AdbServerStatus.known_hosts_path");
    target = stream->WriteStringMaybeAliased(14, _s, target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:adb.proto.AdbServerStatus)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t AdbServerStatus::ByteSizeLong(const MessageLite& base) {
  const AdbServerStatus& this_ = static_cast<const AdbServerStatus&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t AdbServerStatus::ByteSizeLong() const {
  const AdbServerStatus& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:adb.proto.AdbServerStatus)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  total_size += ::absl::popcount(0x00003000U & cached_has_bits) * 2;
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // string version = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_version().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_version());
      }
    }
    // string build = 6;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_build().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_build());
      }
    }
    // string executable_absolute_path = 7;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_executable_absolute_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_executable_absolute_path());
      }
    }
    // string log_absolute_path = 8;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!this_._internal_log_absolute_path().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_log_absolute_path());
      }
    }
    // string os = 9;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!this_._internal_os().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_os());
      }
    }
    // optional string trace_level = 10;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_trace_level());
    }
    // optional string keystore_path = 13;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_keystore_path());
    }
    // optional string known_hosts_path = 14;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_known_hosts_path());
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000f00U)) {
    // .adb.proto.AdbServerStatus.UsbBackend usb_backend = 1;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (this_._internal_usb_backend() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_usb_backend());
      }
    }
    // .adb.proto.AdbServerStatus.MdnsBackend mdns_backend = 3;
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (this_._internal_mdns_backend() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_mdns_backend());
      }
    }
    // bool usb_backend_forced = 2;
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      if (this_._internal_usb_backend_forced() != 0) {
        total_size += 2;
      }
    }
    // bool mdns_backend_forced = 4;
    if (CheckHasBit(cached_has_bits, 0x00000800U)) {
      if (this_._internal_mdns_backend_forced() != 0) {
        total_size += 2;
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void AdbServerStatus::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<AdbServerStatus*>(&to_msg);
  auto& from = static_cast<const AdbServerStatus&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:adb.proto.AdbServerStatus)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_version().empty()) {
        _this->_internal_set_version(from._internal_version());
      } else {
        if (_this->_impl_.version_.IsDefault()) {
          _this->_internal_set_version("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_build().empty()) {
        _this->_internal_set_build(from._internal_build());
      } else {
        if (_this->_impl_.build_.IsDefault()) {
          _this->_internal_set_build("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_executable_absolute_path().empty()) {
        _this->_internal_set_executable_absolute_path(from._internal_executable_absolute_path());
      } else {
        if (_this->_impl_.executable_absolute_path_.IsDefault()) {
          _this->_internal_set_executable_absolute_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!from._internal_log_absolute_path().empty()) {
        _this->_internal_set_log_absolute_path(from._internal_log_absolute_path());
      } else {
        if (_this->_impl_.log_absolute_path_.IsDefault()) {
          _this->_internal_set_log_absolute_path("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      if (!from._internal_os().empty()) {
        _this->_internal_set_os(from._internal_os());
      } else {
        if (_this->_impl_.os_.IsDefault()) {
          _this->_internal_set_os("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _this->_internal_set_trace_level(from._internal_trace_level());
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      _this->_internal_set_keystore_path(from._internal_keystore_path());
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      _this->_internal_set_known_hosts_path(from._internal_known_hosts_path());
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00003f00U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (from._internal_usb_backend() != 0) {
        _this->_impl_.usb_backend_ = from._impl_.usb_backend_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (from._internal_mdns_backend() != 0) {
        _this->_impl_.mdns_backend_ = from._impl_.mdns_backend_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      if (from._internal_usb_backend_forced() != 0) {
        _this->_impl_.usb_backend_forced_ = from._impl_.usb_backend_forced_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000800U)) {
      if (from._internal_mdns_backend_forced() != 0) {
        _this->_impl_.mdns_backend_forced_ = from._impl_.mdns_backend_forced_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00001000U)) {
      _this->_impl_.burst_mode_ = from._impl_.burst_mode_;
    }
    if (CheckHasBit(cached_has_bits, 0x00002000U)) {
      _this->_impl_.mdns_enabled_ = from._impl_.mdns_enabled_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void AdbServerStatus::CopyFrom(const AdbServerStatus& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:adb.proto.AdbServerStatus)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void AdbServerStatus::InternalSwap(AdbServerStatus* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.version_, &other->_impl_.version_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.build_, &other->_impl_.build_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.executable_absolute_path_, &other->_impl_.executable_absolute_path_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.log_absolute_path_, &other->_impl_.log_absolute_path_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.os_, &other->_impl_.os_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.trace_level_, &other->_impl_.trace_level_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.keystore_path_, &other->_impl_.keystore_path_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.known_hosts_path_, &other->_impl_.known_hosts_path_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.mdns_enabled_)
      + sizeof(AdbServerStatus::_impl_.mdns_enabled_)
      - PROTOBUF_FIELD_OFFSET(AdbServerStatus, _impl_.usb_backend_)>(
          reinterpret_cast<char*>(&_impl_.usb_backend_),
          reinterpret_cast<char*>(&other->_impl_.usb_backend_));
}

::google::protobuf::Metadata AdbServerStatus::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

MdnsServices::MdnsServices(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, MdnsServices_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:adb.proto.MdnsServices)
}
PROTOBUF_NDEBUG_INLINE MdnsServices::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::adb::proto::MdnsServices& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        tcp_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::adb::proto::MdnsServices,
              PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsServices, _impl_.tcp_)>()
          , from.tcp_
        }
        ,
        tls_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::adb::proto::MdnsServices,
              PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsServices, _impl_.tls_)>()
          , from.tls_
        }
        ,
        pair_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::adb::proto::MdnsServices,
              PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsServices, _impl_.pair_)>()
          , from.pair_
        }
     {}

MdnsServices::MdnsServices(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const MdnsServices& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, MdnsServices_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  MdnsServices* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:adb.proto.MdnsServices)
}
PROTOBUF_NDEBUG_INLINE MdnsServices::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        tcp_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::adb::proto::MdnsServices,
            PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsServices, _impl_.tcp_)>()
         }
        ,
        tls_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::adb::proto::MdnsServices,
            PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsServices, _impl_.tls_)>()
         }
        ,
        pair_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::adb::proto::MdnsServices,
            PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsServices, _impl_.pair_)>()
         }
     {}

inline void MdnsServices::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
MdnsServices::~MdnsServices() {
  // @@protoc_insertion_point(destructor:adb.proto.MdnsServices)
  SharedDtor(*this);
}
inline void MdnsServices::SharedDtor(MessageLite& self) {
  MdnsServices& this_ = static_cast<MdnsServices&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull MdnsServices_class_data_ =
        MdnsServices::InternalGenerateClassData_(MdnsServices_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
MdnsServices::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&MdnsServices_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(MdnsServices_class_data_.tc_table);
  return MdnsServices_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
MdnsServices::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&MdnsServices_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&MdnsServices_globals_));
  return MdnsServices_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const MdnsServices::ParseTableT_
    MdnsServices::_table_ =
        MdnsServices::InternalGenerateParseTable_(MdnsServices_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void MdnsServices::Clear() {
// @@protoc_insertion_point(message_clear_start:adb.proto.MdnsServices)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.tcp_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.tls_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.pair_.Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL MdnsServices::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const MdnsServices& this_ = static_cast<const MdnsServices&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL MdnsServices::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const MdnsServices& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:adb.proto.MdnsServices)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated .adb.proto.ServiceAdbTcp tcp = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_tcp_size());
         i < n; i++) {
      const auto& repfield = this_._internal_tcp().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              1, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // repeated .adb.proto.ServiceAdbTls tls = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_tls_size());
         i < n; i++) {
      const auto& repfield = this_._internal_tls().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              2, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // repeated .adb.proto.ServiceAdbPairing pair = 3;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_pair_size());
         i < n; i++) {
      const auto& repfield = this_._internal_pair().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              3, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:adb.proto.MdnsServices)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t MdnsServices::ByteSizeLong(const MessageLite& base) {
  const MdnsServices& this_ = static_cast<const MdnsServices&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t MdnsServices::ByteSizeLong() const {
  const MdnsServices& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:adb.proto.MdnsServices)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    // repeated .adb.proto.ServiceAdbTcp tcp = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_tcp_size();
      for (const auto& msg : this_._internal_tcp()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // repeated .adb.proto.ServiceAdbTls tls = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1UL * this_._internal_tls_size();
      for (const auto& msg : this_._internal_tls()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // repeated .adb.proto.ServiceAdbPairing pair = 3;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1UL * this_._internal_pair_size();
      for (const auto& msg : this_._internal_pair()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void MdnsServices::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<MdnsServices*>(&to_msg);
  auto& from = static_cast<const MdnsServices&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:adb.proto.MdnsServices)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_tcp()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_tcp());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _this->_internal_mutable_tls()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_tls());
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_internal_mutable_pair()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_pair());
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void MdnsServices::CopyFrom(const MdnsServices& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:adb.proto.MdnsServices)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void MdnsServices::InternalSwap(MdnsServices* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.tcp_.InternalSwap(&other->_impl_.tcp_);
  _impl_.tls_.InternalSwap(&other->_impl_.tls_);
  _impl_.pair_.InternalSwap(&other->_impl_.pair_);
}

::google::protobuf::Metadata MdnsServices::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

ServiceAdbTcp::ServiceAdbTcp(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ServiceAdbTcp_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:adb.proto.ServiceAdbTcp)
}
PROTOBUF_NDEBUG_INLINE ServiceAdbTcp::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::adb::proto::ServiceAdbTcp& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

ServiceAdbTcp::ServiceAdbTcp(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ServiceAdbTcp& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ServiceAdbTcp_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ServiceAdbTcp* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.service_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.service_)
                : nullptr;

  // @@protoc_insertion_point(copy_constructor:adb.proto.ServiceAdbTcp)
}
PROTOBUF_NDEBUG_INLINE ServiceAdbTcp::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void ServiceAdbTcp::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.service_ = {};
}
ServiceAdbTcp::~ServiceAdbTcp() {
  // @@protoc_insertion_point(destructor:adb.proto.ServiceAdbTcp)
  SharedDtor(*this);
}
inline void ServiceAdbTcp::SharedDtor(MessageLite& self) {
  ServiceAdbTcp& this_ = static_cast<ServiceAdbTcp&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.service_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ServiceAdbTcp_class_data_ =
        ServiceAdbTcp::InternalGenerateClassData_(ServiceAdbTcp_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ServiceAdbTcp::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ServiceAdbTcp_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ServiceAdbTcp_class_data_.tc_table);
  return ServiceAdbTcp_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ServiceAdbTcp::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ServiceAdbTcp_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ServiceAdbTcp_globals_));
  return ServiceAdbTcp_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ServiceAdbTcp::ParseTableT_
    ServiceAdbTcp::_table_ =
        ServiceAdbTcp::InternalGenerateParseTable_(ServiceAdbTcp_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ServiceAdbTcp::Clear() {
// @@protoc_insertion_point(message_clear_start:adb.proto.ServiceAdbTcp)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    ABSL_DCHECK(_impl_.service_ != nullptr);
    _impl_.service_->Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ServiceAdbTcp::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ServiceAdbTcp& this_ = static_cast<const ServiceAdbTcp&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ServiceAdbTcp::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ServiceAdbTcp& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:adb.proto.ServiceAdbTcp)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .adb.proto.MdnsService service = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.service_, this_._impl_.service_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:adb.proto.ServiceAdbTcp)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ServiceAdbTcp::ByteSizeLong(const MessageLite& base) {
  const ServiceAdbTcp& this_ = static_cast<const ServiceAdbTcp&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ServiceAdbTcp::ByteSizeLong() const {
  const ServiceAdbTcp& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:adb.proto.ServiceAdbTcp)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

   {
    // .adb.proto.MdnsService service = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.service_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ServiceAdbTcp::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ServiceAdbTcp*>(&to_msg);
  auto& from = static_cast<const ServiceAdbTcp&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:adb.proto.ServiceAdbTcp)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    ABSL_DCHECK(from._impl_.service_ != nullptr);
    if (_this->_impl_.service_ == nullptr) {
      _this->_impl_.service_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.service_);
    } else {
      _this->_impl_.service_->MergeFrom(*from._impl_.service_);
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ServiceAdbTcp::CopyFrom(const ServiceAdbTcp& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:adb.proto.ServiceAdbTcp)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ServiceAdbTcp::InternalSwap(ServiceAdbTcp* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.service_, other->_impl_.service_);
}

::google::protobuf::Metadata ServiceAdbTcp::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

ServiceAdbTls::ServiceAdbTls(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ServiceAdbTls_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:adb.proto.ServiceAdbTls)
}
PROTOBUF_NDEBUG_INLINE ServiceAdbTls::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::adb::proto::ServiceAdbTls& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

ServiceAdbTls::ServiceAdbTls(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ServiceAdbTls& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ServiceAdbTls_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ServiceAdbTls* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.service_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.service_)
                : nullptr;
  _impl_.known_device_ = from._impl_.known_device_;

  // @@protoc_insertion_point(copy_constructor:adb.proto.ServiceAdbTls)
}
PROTOBUF_NDEBUG_INLINE ServiceAdbTls::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void ServiceAdbTls::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, service_),
           0,
           offsetof(Impl_, known_device_) -
               offsetof(Impl_, service_) +
               sizeof(Impl_::known_device_));
}
ServiceAdbTls::~ServiceAdbTls() {
  // @@protoc_insertion_point(destructor:adb.proto.ServiceAdbTls)
  SharedDtor(*this);
}
inline void ServiceAdbTls::SharedDtor(MessageLite& self) {
  ServiceAdbTls& this_ = static_cast<ServiceAdbTls&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.service_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ServiceAdbTls_class_data_ =
        ServiceAdbTls::InternalGenerateClassData_(ServiceAdbTls_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ServiceAdbTls::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ServiceAdbTls_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ServiceAdbTls_class_data_.tc_table);
  return ServiceAdbTls_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ServiceAdbTls::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ServiceAdbTls_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ServiceAdbTls_globals_));
  return ServiceAdbTls_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ServiceAdbTls::ParseTableT_
    ServiceAdbTls::_table_ =
        ServiceAdbTls::InternalGenerateParseTable_(ServiceAdbTls_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ServiceAdbTls::Clear() {
// @@protoc_insertion_point(message_clear_start:adb.proto.ServiceAdbTls)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    ABSL_DCHECK(_impl_.service_ != nullptr);
    _impl_.service_->Clear();
  }
  _impl_.known_device_ = false;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ServiceAdbTls::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ServiceAdbTls& this_ = static_cast<const ServiceAdbTls&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ServiceAdbTls::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ServiceAdbTls& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:adb.proto.ServiceAdbTls)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .adb.proto.MdnsService service = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.service_, this_._impl_.service_->GetCachedSize(), target,
        stream);
  }

  // bool known_device = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (this_._internal_known_device() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          2, this_._internal_known_device(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:adb.proto.ServiceAdbTls)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ServiceAdbTls::ByteSizeLong(const MessageLite& base) {
  const ServiceAdbTls& this_ = static_cast<const ServiceAdbTls&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ServiceAdbTls::ByteSizeLong() const {
  const ServiceAdbTls& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:adb.proto.ServiceAdbTls)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // .adb.proto.MdnsService service = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.service_);
    }
    // bool known_device = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (this_._internal_known_device() != 0) {
        total_size += 2;
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ServiceAdbTls::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ServiceAdbTls*>(&to_msg);
  auto& from = static_cast<const ServiceAdbTls&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:adb.proto.ServiceAdbTls)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.service_ != nullptr);
      if (_this->_impl_.service_ == nullptr) {
        _this->_impl_.service_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.service_);
      } else {
        _this->_impl_.service_->MergeFrom(*from._impl_.service_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (from._internal_known_device() != 0) {
        _this->_impl_.known_device_ = from._impl_.known_device_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ServiceAdbTls::CopyFrom(const ServiceAdbTls& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:adb.proto.ServiceAdbTls)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ServiceAdbTls::InternalSwap(ServiceAdbTls* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(ServiceAdbTls, _impl_.known_device_)
      + sizeof(ServiceAdbTls::_impl_.known_device_)
      - PROTOBUF_FIELD_OFFSET(ServiceAdbTls, _impl_.service_)>(
          reinterpret_cast<char*>(&_impl_.service_),
          reinterpret_cast<char*>(&other->_impl_.service_));
}

::google::protobuf::Metadata ServiceAdbTls::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

ServiceAdbPairing::ServiceAdbPairing(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ServiceAdbPairing_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:adb.proto.ServiceAdbPairing)
}
PROTOBUF_NDEBUG_INLINE ServiceAdbPairing::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::adb::proto::ServiceAdbPairing& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

ServiceAdbPairing::ServiceAdbPairing(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ServiceAdbPairing& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ServiceAdbPairing_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ServiceAdbPairing* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.service_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.service_)
                : nullptr;

  // @@protoc_insertion_point(copy_constructor:adb.proto.ServiceAdbPairing)
}
PROTOBUF_NDEBUG_INLINE ServiceAdbPairing::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void ServiceAdbPairing::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.service_ = {};
}
ServiceAdbPairing::~ServiceAdbPairing() {
  // @@protoc_insertion_point(destructor:adb.proto.ServiceAdbPairing)
  SharedDtor(*this);
}
inline void ServiceAdbPairing::SharedDtor(MessageLite& self) {
  ServiceAdbPairing& this_ = static_cast<ServiceAdbPairing&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.service_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ServiceAdbPairing_class_data_ =
        ServiceAdbPairing::InternalGenerateClassData_(ServiceAdbPairing_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ServiceAdbPairing::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ServiceAdbPairing_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ServiceAdbPairing_class_data_.tc_table);
  return ServiceAdbPairing_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ServiceAdbPairing::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ServiceAdbPairing_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ServiceAdbPairing_globals_));
  return ServiceAdbPairing_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ServiceAdbPairing::ParseTableT_
    ServiceAdbPairing::_table_ =
        ServiceAdbPairing::InternalGenerateParseTable_(ServiceAdbPairing_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ServiceAdbPairing::Clear() {
// @@protoc_insertion_point(message_clear_start:adb.proto.ServiceAdbPairing)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    ABSL_DCHECK(_impl_.service_ != nullptr);
    _impl_.service_->Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ServiceAdbPairing::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ServiceAdbPairing& this_ = static_cast<const ServiceAdbPairing&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ServiceAdbPairing::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ServiceAdbPairing& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:adb.proto.ServiceAdbPairing)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .adb.proto.MdnsService service = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.service_, this_._impl_.service_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:adb.proto.ServiceAdbPairing)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ServiceAdbPairing::ByteSizeLong(const MessageLite& base) {
  const ServiceAdbPairing& this_ = static_cast<const ServiceAdbPairing&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ServiceAdbPairing::ByteSizeLong() const {
  const ServiceAdbPairing& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:adb.proto.ServiceAdbPairing)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

   {
    // .adb.proto.MdnsService service = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.service_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ServiceAdbPairing::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ServiceAdbPairing*>(&to_msg);
  auto& from = static_cast<const ServiceAdbPairing&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:adb.proto.ServiceAdbPairing)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    ABSL_DCHECK(from._impl_.service_ != nullptr);
    if (_this->_impl_.service_ == nullptr) {
      _this->_impl_.service_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.service_);
    } else {
      _this->_impl_.service_->MergeFrom(*from._impl_.service_);
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ServiceAdbPairing::CopyFrom(const ServiceAdbPairing& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:adb.proto.ServiceAdbPairing)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ServiceAdbPairing::InternalSwap(ServiceAdbPairing* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.service_, other->_impl_.service_);
}

::google::protobuf::Metadata ServiceAdbPairing::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

MdnsService::MdnsService(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, MdnsService_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:adb.proto.MdnsService)
}
PROTOBUF_NDEBUG_INLINE MdnsService::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::adb::proto::MdnsService& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        ipv6_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::adb::proto::MdnsService,
              PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.ipv6_)>()
          , from.ipv6_
        }
        ,
        instance_(arena, from.instance_),
        service_(arena, from.service_),
        domain_(arena, from.domain_),
        ipv4_(arena, from.ipv4_),
        product_model_(arena, from.product_model_),
        build_version_sdk_full_(arena, from.build_version_sdk_full_),
        given_name_(arena, from.given_name_),
        serial_(arena, from.serial_),
        mdns_service_version_(arena, from.mdns_service_version_),
        hostname_(arena, from.hostname_) {}

MdnsService::MdnsService(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const MdnsService& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, MdnsService_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  MdnsService* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  _impl_.port_ = from._impl_.port_;

  // @@protoc_insertion_point(copy_constructor:adb.proto.MdnsService)
}
PROTOBUF_NDEBUG_INLINE MdnsService::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        ipv6_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::adb::proto::MdnsService,
            PROTOBUF_FIELD_OFFSET(::adb::proto::MdnsService, _impl_.ipv6_)>()
         }
        ,
        instance_(arena),
        service_(arena),
        domain_(arena),
        ipv4_(arena),
        product_model_(arena),
        build_version_sdk_full_(arena),
        given_name_(arena),
        serial_(arena),
        mdns_service_version_(arena),
        hostname_(arena) {}

inline void MdnsService::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.port_ = {};
}
MdnsService::~MdnsService() {
  // @@protoc_insertion_point(destructor:adb.proto.MdnsService)
  SharedDtor(*this);
}
inline void MdnsService::SharedDtor(MessageLite& self) {
  MdnsService& this_ = static_cast<MdnsService&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.instance_.Destroy();
  this_._impl_.service_.Destroy();
  this_._impl_.domain_.Destroy();
  this_._impl_.ipv4_.Destroy();
  this_._impl_.product_model_.Destroy();
  this_._impl_.build_version_sdk_full_.Destroy();
  this_._impl_.given_name_.Destroy();
  this_._impl_.serial_.Destroy();
  this_._impl_.mdns_service_version_.Destroy();
  this_._impl_.hostname_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull MdnsService_class_data_ =
        MdnsService::InternalGenerateClassData_(MdnsService_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
MdnsService::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&MdnsService_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(MdnsService_class_data_.tc_table);
  return MdnsService_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
MdnsService::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&MdnsService_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&MdnsService_globals_));
  return MdnsService_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const MdnsService::ParseTableT_
    MdnsService::_table_ =
        MdnsService::InternalGenerateParseTable_(MdnsService_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void MdnsService::Clear() {
// @@protoc_insertion_point(message_clear_start:adb.proto.MdnsService)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.ipv6_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.instance_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.service_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.domain_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _impl_.ipv4_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _impl_.product_model_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      _impl_.build_version_sdk_full_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      _impl_.given_name_.ClearNonDefaultToEmpty();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000700U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      _impl_.serial_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      _impl_.mdns_service_version_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      _impl_.hostname_.ClearNonDefaultToEmpty();
    }
  }
  _impl_.port_ = 0u;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL MdnsService::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const MdnsService& this_ = static_cast<const MdnsService&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL MdnsService::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const MdnsService& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:adb.proto.MdnsService)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string instance = 1;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_instance().empty()) {
      const ::std::string& _s = this_._internal_instance();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.MdnsService.instance");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string service = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_service().empty()) {
      const ::std::string& _s = this_._internal_service();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.MdnsService.service");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  // string domain = 3;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (!this_._internal_domain().empty()) {
      const ::std::string& _s = this_._internal_domain();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.MdnsService.domain");
      target = stream->WriteStringMaybeAliased(3, _s, target);
    }
  }

  // optional string ipv4 = 4;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    const ::std::string& _s = this_._internal_ipv4();
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
        _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.MdnsService.ipv4");
    target = stream->WriteStringMaybeAliased(4, _s, target);
  }

  // repeated string ipv6 = 5;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (int i = 0, n = this_._internal_ipv6_size(); i < n; ++i) {
      const auto& s = this_._internal_ipv6().Get(i);
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          s.data(), static_cast<int>(s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.MdnsService.ipv6");
      target = stream->WriteString(5, s, target);
    }
  }

  // uint32 port = 6;
  if (CheckHasBit(cached_has_bits, 0x00000800U)) {
    if (this_._internal_port() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteUInt32ToArray(
          6, this_._internal_port(), target);
    }
  }

  // optional string product_model = 7;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    const ::std::string& _s = this_._internal_product_model();
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
        _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.MdnsService.product_model");
    target = stream->WriteStringMaybeAliased(7, _s, target);
  }

  // optional string build_version_sdk_full = 8;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    const ::std::string& _s = this_._internal_build_version_sdk_full();
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
        _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.MdnsService.build_version_sdk_full");
    target = stream->WriteStringMaybeAliased(8, _s, target);
  }

  // optional string given_name = 9;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    const ::std::string& _s = this_._internal_given_name();
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
        _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.MdnsService.given_name");
    target = stream->WriteStringMaybeAliased(9, _s, target);
  }

  // optional string serial = 10;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    const ::std::string& _s = this_._internal_serial();
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
        _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.MdnsService.serial");
    target = stream->WriteStringMaybeAliased(10, _s, target);
  }

  // optional string mdns_service_version = 11;
  if (CheckHasBit(cached_has_bits, 0x00000200U)) {
    const ::std::string& _s = this_._internal_mdns_service_version();
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
        _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.MdnsService.mdns_service_version");
    target = stream->WriteStringMaybeAliased(11, _s, target);
  }

  // optional string hostname = 12;
  if (CheckHasBit(cached_has_bits, 0x00000400U)) {
    const ::std::string& _s = this_._internal_hostname();
    ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
        _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "adb.proto.MdnsService.hostname");
    target = stream->WriteStringMaybeAliased(12, _s, target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:adb.proto.MdnsService)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t MdnsService::ByteSizeLong(const MessageLite& base) {
  const MdnsService& this_ = static_cast<const MdnsService&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t MdnsService::ByteSizeLong() const {
  const MdnsService& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:adb.proto.MdnsService)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // repeated string ipv6 = 5;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size +=
          1 * ::google::protobuf::internal::FromIntSize(this_._internal_ipv6().size());
      for (int i = 0, n = this_._internal_ipv6().size(); i < n; ++i) {
        total_size += ::google::protobuf::internal::WireFormatLite::StringSize(
            this_._internal_ipv6().Get(i));
      }
    }
    // string instance = 1;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_instance().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_instance());
      }
    }
    // string service = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_service().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_service());
      }
    }
    // string domain = 3;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!this_._internal_domain().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_domain());
      }
    }
    // optional string ipv4 = 4;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_ipv4());
    }
    // optional string product_model = 7;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_product_model());
    }
    // optional string build_version_sdk_full = 8;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_build_version_sdk_full());
    }
    // optional string given_name = 9;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_given_name());
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000f00U)) {
    // optional string serial = 10;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_serial());
    }
    // optional string mdns_service_version = 11;
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_mdns_service_version());
    }
    // optional string hostname = 12;
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                      this_._internal_hostname());
    }
    // uint32 port = 6;
    if (CheckHasBit(cached_has_bits, 0x00000800U)) {
      if (this_._internal_port() != 0) {
        total_size += ::_pbi::WireFormatLite::UInt32SizePlusOne(
            this_._internal_port());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void MdnsService::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<MdnsService*>(&to_msg);
  auto& from = static_cast<const MdnsService&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:adb.proto.MdnsService)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_ipv6()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_ipv6());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_instance().empty()) {
        _this->_internal_set_instance(from._internal_instance());
      } else {
        if (_this->_impl_.instance_.IsDefault()) {
          _this->_internal_set_instance("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_service().empty()) {
        _this->_internal_set_service(from._internal_service());
      } else {
        if (_this->_impl_.service_.IsDefault()) {
          _this->_internal_set_service("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!from._internal_domain().empty()) {
        _this->_internal_set_domain(from._internal_domain());
      } else {
        if (_this->_impl_.domain_.IsDefault()) {
          _this->_internal_set_domain("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      _this->_internal_set_ipv4(from._internal_ipv4());
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      _this->_internal_set_product_model(from._internal_product_model());
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      _this->_internal_set_build_version_sdk_full(from._internal_build_version_sdk_full());
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      _this->_internal_set_given_name(from._internal_given_name());
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000f00U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      _this->_internal_set_serial(from._internal_serial());
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      _this->_internal_set_mdns_service_version(from._internal_mdns_service_version());
    }
    if (CheckHasBit(cached_has_bits, 0x00000400U)) {
      _this->_internal_set_hostname(from._internal_hostname());
    }
    if (CheckHasBit(cached_has_bits, 0x00000800U)) {
      if (from._internal_port() != 0) {
        _this->_impl_.port_ = from._impl_.port_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void MdnsService::CopyFrom(const MdnsService& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:adb.proto.MdnsService)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void MdnsService::InternalSwap(MdnsService* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.ipv6_.InternalSwap(&other->_impl_.ipv6_);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.instance_, &other->_impl_.instance_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.service_, &other->_impl_.service_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.domain_, &other->_impl_.domain_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.ipv4_, &other->_impl_.ipv4_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.product_model_, &other->_impl_.product_model_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.build_version_sdk_full_, &other->_impl_.build_version_sdk_full_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.given_name_, &other->_impl_.given_name_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.serial_, &other->_impl_.serial_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.mdns_service_version_, &other->_impl_.mdns_service_version_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.hostname_, &other->_impl_.hostname_, arena);
  swap(_impl_.port_, other->_impl_.port_);
}

::google::protobuf::Metadata MdnsService::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace proto
}  // namespace adb
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_adb_5fhost_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
